# -*- coding: utf-8 -*-
from .pysendy import *

"""
See PEP 386 (http://www.python.org/dev/peps/pep-0386/)

Release logic:
1. Remove "dev" from current.
2. git commit
3. git tag <version>
4. push to pypi (python setup.py sdist upload) + push to github
5. bump the version, append '.dev0'
6. git commit
7. push to github (to avoid confusion)
"""

__author__ = 'Thiago Faria de Andrade'
__copyright__ = 'Copyright 2013, Thiago Faria de Andrade'
__credits__ = ['Thiago Faria de Andrade',]



# -*- coding: utf-8 -*-
class SendyException(Exception): pass
class UserException(SendyException): pass
class HttpRequestException(SendyException): pass

class InvalidEmailAddressException(UserException): pass
class AlreadySubscribedException(UserException): pass
class SomeFieldsAreMissingException(UserException): pass

class InvalidListIdException(SendyException): pass

SUBSCRIPTION_ERRORS = {
    'Already subscribed.': AlreadySubscribedException,
    'Invalid email address.': InvalidEmailAddressException,
    'Some fields are missing.': SomeFieldsAreMissingException,
    'Invalid list ID.': InvalidListIdException,
}

UNSUBSCRIPTION_ERRORS = {
	'Some fields are missing.': SomeFieldsAreMissingException,
	'Invalid email address.': InvalidListIdException,
}


#!/usr/bin/env python
from setuptools import setup, find_packages

version = '0.0.5'

setup(
    name='pysendy',
    version=version,
    description='Sendy API v1.1.7 for Python.',
    long_description=open('README.md').read(),
    author='Thiago Faria de Andrade',
    author_email='thiagofa@gmail.com',
    url='https://github.com/thiagofa/pysendy',
    packages=find_packages(),
    download_url='http://pypi.python.org/pypi/pysendy/',
    keywords='pysendy sendy sendy.co wrapper api',
    zip_safe=True,
    install_requires=['requests'],
    py_modules=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)


# -*- coding: utf-8 -*-
from .exceptions import *
import requests

class Sendy(object):

    def __init__(self, base_url, api_key=''):
        self.api_key = api_key
        self.base_url = base_url

    def subscribe(self, name='', email='', list_id='', **fields):
        params = {'name': name, 'email': email, 'list': list_id}
        for key, val in fields.items():
            params.update({key:val})
        self._post('/subscribe', params, SUBSCRIPTION_ERRORS)

    def unsubscribe(self, email='', list_id=''):
        params = {'email': email, 'list': list_id}
        self._post('/unsubscribe', params, UNSUBSCRIPTION_ERRORS)

    def _post(self, path, params, errors):
        url = self.base_url + path
        _params = {'boolean': 'true'}
        _params.update(params)

        try:
            response = requests.post(url, data=_params)
            success = response.text == '1'
        
            if not success:
                try:
                    err = errors[response.text](response.text)
                except KeyError:
                    err = UserException('Failed [' + path + ']: ' + response.text)

                raise err

        except requests.exceptions.RequestException as e:
            raise HttpRequestException(e.message)

        if response.status_code != 200:
            raise HttpRequestException(response.status_code)
